clear all
clc
[x y] = ode45(@EX2_2function, [0 15], zeros(1,8));
alpha = 2*pi/3;
f = 60;
omega = 2*pi*f;
V_phase = 690*((2/3)^0.5);
J = 70;
T_l = 0;

theta_m = y(:,1);
omega_m = y(:,2);
I = y(:,3:8);

p = 6; %number of poles
Xm = (2/3)*0.86;    %Single phase Magnetizing reactance
Xls = 0.05;   %Stator leakage reactance
Xlr = 0.047;   %Rotor leakage reactance
Rs = 0.002;   %Stator winding resistance
Rr = 0.0015; %Rotor resistance
Lm = Xm/omega; %Single phase magnetizing inductance
Lls = Xls/omega; %Stator leakage inductance
Llr = Xlr/omega; %Rotor leakage inductance
ks = Lls/Lm;  %Ratio of stator leakage inductance and single 
              %phase magnetizing inductance
kr = Llr/Lm;  %Ratio of rotor leakage inductance and single 
              %phase magnetizing inductance
R = [Rs*eye(3), zeros(3); zeros(3), Rr*eye(3)]; %Resistance matrix
              
Lss = Lm*[1+ks, cos(alpha), cos(2*alpha); %Stator self inductance matrix
    cos(2*alpha), 1+ks, cos(alpha);
    cos(alpha), cos(2*alpha), 1+ks];
Lrr = Lm*[1+kr, cos(alpha), cos(2*alpha); %Rotor self inductance matrix
    cos(2*alpha), 1+kr, cos(alpha);
    cos(alpha), cos(2*alpha), 1+kr];
T_em = zeros(length(x),1);

for i=1:length(x)
   
   dLsr_dtheta_m = -Lm*[sin(theta_m(i)), sin(theta_m(i)+alpha), sin(theta_m(i)+2*alpha);
    sin(theta_m(i)+2*alpha), sin(theta_m(i)), sin(theta_m(i)+alpha); %Derivative
    sin(theta_m(i)+alpha), sin(theta_m(i)+2*alpha), sin(theta_m(i))]; %of Lsr wrt 
                                                            %theta_m
   dL_dtheta_m = [zeros(3), dLsr_dtheta_m; dLsr_dtheta_m.', zeros(3)];
   T_em(i) = (p/4) * ((I(i,1:6))*dL_dtheta_m*(I(i,1:6))');
end
plot(x, 60*y(:,2)/(2*pi*3));
grid on;
ylabel('Speed(rpm)');
xlabel('Time(s)');
figure(2);
plot(x, T_em);
grid on;
ylabel('Torque(Nm)');
xlabel('Time(s)');
figure(3);
plot(60*y(:,2)/(2*pi*3), T_em);
grid on;
xlabel('Speed(rpm)');
ylabel('Torque(Nm)');
figure(4);
plot(x, y(:,3:5));
grid on;
ylabel('Stator currents(A)');
xlabel('Time(s)');
figure(5)
plot(x, y(:,6:8));
grid on;
ylabel('Rotor currents(A)');
xlabel('Time(s)');