function dy = IM_abc_start(t, y)
%theta_m = 0;  %Initial electrical angle between stator a and rotor A axis
alpha = 2*pi/3;
f = 60;
omega = 2*pi*f;
V_phase = 690*((2/3)^0.5);
J = 70;
T_l = 0;

V = V_phase*[cos(omega*t); cos(omega*t-alpha); cos(omega*t+alpha); 0; 0; 0];

theta_m = y(1);
omega_m = y(2);
I = y(3:8);

p = 6; %number of poles
Xm = (2/3)*0.86;    %Single phase Magnetizing reactance
Xls = 0.05;   %Stator leakage reactance
Xlr = 0.047;   %Rotor leakage reactance
Rs = 0.002;   %Stator winding resistance
Rr = 0.0015; %Rotor resistance
Lm = Xm/omega; %Single phase magnetizing inductance
Lls = Xls/omega; %Stator leakage inductance
Llr = Xlr/omega; %Rotor leakage inductance
ks = Lls/Lm;  %Ratio of stator leakage inductance and single 
              %phase magnetizing inductance
kr = Llr/Lm;  %Ratio of rotor leakage inductance and single 
              %phase magnetizing inductance
              
Lss = Lm*[1+ks, cos(alpha), cos(2*alpha); %Stator self inductance matrix
    cos(2*alpha), 1+ks, cos(alpha);
    cos(alpha), cos(2*alpha), 1+ks];

Lrr = Lm*[1+kr, cos(alpha), cos(2*alpha); %Rotor self inductance matrix
    cos(2*alpha), 1+kr, cos(alpha);
    cos(alpha), cos(2*alpha), 1+kr];

Lsr = Lm*[cos(theta_m), cos(theta_m+alpha), cos(theta_m+2*alpha);
    cos(theta_m+2*alpha), cos(theta_m), cos(theta_m+alpha); %Stator rotor
    cos(theta_m+alpha), cos(theta_m+2*alpha), cos(theta_m)]; %mutual inductance

Lrs = Lsr.'; %Rotor stator mutual inductance is transpose (no conjugate) of Lsr

L = [Lss, Lsr; Lrs, Lrr]; %The complete inductance matrix

dLsr_dtheta_m = -Lm*[sin(theta_m), sin(theta_m+alpha), sin(theta_m+2*alpha);
    sin(theta_m+2*alpha), sin(theta_m), sin(theta_m+alpha); %Derivative
    sin(theta_m+alpha), sin(theta_m+2*alpha), sin(theta_m)]; %of Lsr wrt 
                                                            %theta_m
dL_dtheta_m = [zeros(3), dLsr_dtheta_m; dLsr_dtheta_m.', zeros(3)];

R = [Rs*eye(3), zeros(3); zeros(3), Rr*eye(3)]; %Resistance matrix

T_em = (p/4) * (I.')*dL_dtheta_m*I;
dI_dt = inv(L)*(V-(R+omega_m*dL_dtheta_m)*I);
domega_m_dt = (p/2)* (T_em-T_l)/J;

dy=zeros(8,1);
dy(1) = omega_m;
dy(2) = domega_m_dt;
dy(3:8) = dI_dt;


                                             


