clear all
clc
% Example 3-1 File Name EX3_1.m
% Calculation of Initial Conditions
% Induction Motor Parameters
Rs=1.77;
Rr=1.34;
Xls=5.25;
Xlr=4.57;
Xm=139;
Jeq=0.025;
p=4;

% Steady State Operating Condition
f=60; VLLrms= 460; s=0.0172;  % phase-a voltage is at its positive peak at t=0
Wsyn=2*pi*f;                                            % synchronous speed in electrical rad/s
Wm=(1-s)*Wsyn;                                          % rotor speed in electrical rad/s

% Phasor Calculations
Va = VLLrms * sqrt(2)/ sqrt(3)                         % Va phasor
Zrotor = j*Xlr + Rr/s;                                  % Equivalent Rotor Branch Impedance
Zm = j*Xm;                                              % Magnetizing Impedance
Zeq = (Rs + j*Xls) +  (Zm * Zrotor) / (Zm + Zrotor);    % Equivalent Impedance 
Ia = Va / Zeq                                          % Ia phasor
Ema = Va - (Rs + j*Xls) * Ia                           % Voltage across the magnetizing branch
Iraprime = Ema / Zrotor                                % Rotor branch current phasor

% Space Vectors at time t=0 with stator a-axis as the reference
Vs_0 = (3/2) * Va                                      % Vs(0) space vector
Is_0 = (3/2) * Ia                                      % Is(0) space vector 
Theta_Is_0 = angle(Is_0)                               % angle of Is(0) space vector
Ir_0 = (-1) * (3/2) * Iraprime                         % Ir(0) space vector; notice factor of (-1); see Fig. 3-11 
Theta_Ir_0 = angle(Ir_0)                               % angle of Ir(0) space vector
% We will assume that at t=0, d-axis is aligned to the stator a-axis.  Therefore, Theta_da_0=0
Theta_da_0 = 0
Isd_0 = sqrt(2/3) * abs(Is_0) * cos(Theta_Is_0 - Theta_da_0) % Eq. 3-64
Isq_0 = sqrt(2/3) * abs(Is_0) * sin(Theta_Is_0 - Theta_da_0) % Eq. 3-65
Ird_0 = sqrt(2/3) * abs(Ir_0) * cos(Theta_Ir_0 - Theta_da_0)
Irq_0 = sqrt(2/3) * abs(Ir_0) * sin(Theta_Ir_0 - Theta_da_0)

% Calculation of machine inductances 
Ls = (Xls + Xm) / (2*pi*f);
Lm = Xm / (2*pi*f);
Lr = (Xlr + Xm) / (2*pi*f);

% Inductance matrix M in Eq. 3-61
M = [Ls 0  Lm 0 ;...
     0  Ls 0  Lm;...
     Lm 0  Lr 0 ;...
     0  Lm 0  Lr];

% Flux Linkages
fl_dq_0 = M * [Isd_0; Isq_0; Ird_0; Irq_0];    % dq-winding fluxes in vector form, Eq. 3-61
fl_sd_0 = fl_dq_0(1)
fl_sq_0 = fl_dq_0(2)         
fl_rd_0 = fl_dq_0(3)
fl_rq_0 = fl_dq_0(4)

% Electromagnetic Torque, which equals Load Torque in Initial Steady State
Tem_0 = (p/2) * Lm * (Isq_0 * Ird_0 - Isd_0 * Irq_0)    % Eq. 3-47
TL_0 = Tem_0

% Wmech = rotor speed in actual rad/s
Wmech_0=(2/p)*Wm  %Eq. 3-34