clear all
clc
omega_mech_syn = 2*pi*60/(6/2);
Wsyn = 2*pi*60;
Vphase = 690/(3^0.5);
Xm = 0.86;
Xls = 0.05;
Xlr = 0.047;
Rs = 0.002;
Rr = 0.0015; 
s = 0.01;
p=6;
Jeq=70.0;
VLLrms= 690;

Lm = (Xm/Wsyn);
Lls = Xls/Wsyn;
Llr = Xlr/Wsyn;
Ls = Lm+Lls;
Lr = Lm+Llr;
tau_r=Lr/Rr;
L = [Ls, 0, Lm, 0;
     0, Ls, 0, Lm;
     Lm, 0, Lr, 0;
     0, Lm, 0, Lr];

Zs = Rs + 1i*Xls;
Zr = Rr/s + 1i*Xlr;
Zm = 1i*Xm;
Z = Zs + Zm*Zr/(Zm+Zr);
Isphase = Vphase/Z;
Irphase = Isphase*Zm/(Zm+Zr);
P_out = 3*(abs(Irphase)^2)*Rr*(1-s)/s;
Torque = P_out/(omega_mech_syn*(1-s));

Is = (3/2)*(2^0.5)*Isphase;
Ir = -(3/2)*(2^0.5)*Irphase; %Ir is in opposite direction in the dq model as 
                         %compared to the equivalent circuit
theta_Is_0 = angle(Is);
theta_Ir_0 = angle(Ir);
% (a)
%Initial conditions for synchronous frame. Voltage vector, d axis and rotor
%A axis are assumed to be aligned along stator a axis initially
% Vsd = (3/2)*Vphase;
% Vsq = 0;
theta_da_0 = 0;
theta_dA_0 = 0;
theta_m_0 = theta_da_0 - theta_dA_0;
omega_m_0 = Wsyn*(1-s)
Isdq_syn_0 = ((2/3)^0.5) * Is * exp(1i*(-theta_da_0));
Irdq_syn_0 = ((2/3)^0.5) * Ir * exp(1i*(-theta_da_0));
disp('(a)')
Isd_0 = real(Isdq_syn_0)
Isq_0 = imag(Isdq_syn_0)
Ird_0 = real(Irdq_syn_0)
Irq_0 = imag(Irdq_syn_0)
lambda_dq_synframe = L*[Isd_0; Isq_0; Ird_0; Irq_0]
fl_sd_0=lambda_dq_synframe(1)
fl_sq_0=lambda_dq_synframe(2)
fl_rd_0=lambda_dq_synframe(3)
fl_rq_0=lambda_dq_synframe(4)
T_em = (p/2)*Lm*(Isq_0 * Ird_0 - Isd_0 * Irq_0)
TL_0 = T_em
Wmech_0=(2/p)*omega_m_0

% (b)
%Initial conditions for rotor frame. Voltage vector, d axis and rotor
%A axis are assumed to be aligned along stator a axis 0ially
disp('(b)')
Is_d_rframe_0 = Isd_0
Is_q_rframe_0 = Isq_0
Ir_d_rframe_0 = Ird_0
Ir_q_rframe_0 = Irq_0

% (c)
%Initial conditions for rotor flux frame.
I_dq = [Isd_0; Isq_0; Ird_0; Irq_0];
Fl_dq = L*I_dq;
Fl_s = Fl_dq(1)+Fl_dq(2)*1i;
Fl_r = Fl_dq(3)+Fl_dq(4)*1i;
fl_s_angle = angle(Fl_s);
fl_r_angle = angle(Fl_r);
theta_da_flrframe = fl_r_angle
theta_dA_flrframe = theta_dA_0 + (theta_da_flrframe - theta_da_0)

Fl_s_flrframe = Fl_s * exp(-1i*theta_da_flrframe);
disp('(c)')
Fl_s_d_flrframe = real(Fl_s_flrframe)
Fl_s_q_flrframe = imag(Fl_s_flrframe)
Fl_r_d_flrframe = abs(Fl_r)
Fl_r_q_flrframe = 0
Idq_0_flrframe = inv(L)*[Fl_s_d_flrframe; Fl_s_q_flrframe; Fl_r_d_flrframe; Fl_r_q_flrframe]




