clear all
clc
% Example 5-1 File Name EX5_1calc.m
% Calculation of Initial Conditions
% Induction Motor Parameters
Rs=1.77;
Rr=1.34;
Xls=5.25;
Xlr=4.57;
Xm=139;
Jeq=0.025;
p=4;

% Steady State Operating Condition
f=60; VLLrms= 460; s=0.0172;                            % phase-a voltage is at its positive peak at t=0
Wsyn=2*pi*f;                                            % synchronous speed in electrical rad/s
Wm=(1-s)*Wsyn;                                          % rotor speed in electrical rad/s

% Phasor Calculations
Va = VLLrms * sqrt(2)/ sqrt(3);                         % Va phasor

% Space Vectors at time t=0 with stator a-axis as the reference
Vs_0 = (3/2) * Va;                                      % Vs(0) space vector
Theta_Vs_0 = angle(Vs_0);                               % angle of Vs(0) space vector

% We will assume that at t=0, d-axis is aligned to the stator a-axis.  Therefore, Theta_da_0=0
Theta_da_0 = 0;
Vsd_0 = sqrt(2/3) * abs(Vs_0) * cos(Theta_Vs_0 - Theta_da_0); % similar to Eq. 3-64
Vsq_0 = sqrt(2/3) * abs(Vs_0) * sin(Theta_Vs_0 - Theta_da_0); % similar to Eq. 3-65

% Calculation of machine inductances 
Ls = (Xls + Xm) / (2*pi*f);
Lm = Xm / (2*pi*f);
Lr = (Xlr + Xm) / (2*pi*f);
tau_r=Lr/Rr;

% Inductance matrix M in Eq. 3-61
M = [Ls 0  Lm 0 ;...
     0  Ls 0  Lm;...
     Lm 0  Lr 0 ;...
     0  Lm 0  Lr];

% Calculations of dq-winding currents
A = [Rs        -Wsyn*Ls       0         -Wsyn*Lm  ;...
     Wsyn*Ls    Rs            Wsyn*Lm    0        ;...
     0         -s*Wsyn*Lm     Rr        -s*Wsyn*Lr;...      % Matrix [A] in Eq. 3-70
     s*Wsyn*Lm  0             s*Wsyn*Lr  Rr];

Ainv = inv(A);
V_dq_0=[Vsd_0; Vsq_0; 0; 0];
I_dq_0=Ainv*V_dq_0;
Isd_0=I_dq_0(1);
Isq_0=I_dq_0(2);
Ird_0=I_dq_0(3);
Irq_0=I_dq_0(4);

% Electromagnetic Torque, which equals Load Torque in Initial Steady State
Tem_0 = (p/2) * Lm * (Isq_0 * Ird_0 - Isd_0 * Irq_0)    % Eq. 3-47
TL_0 = Tem_0;

% Wmech = rotor speed in actual rad/s
Wmech_0=(2/p)*Wm      % Eq. 3-34          


% dq winding Flux Linkages with the d-axis aligned with the stator a-axis
fl_dq_0 = M * [Isd_0; Isq_0; Ird_0; Irq_0];    % dq-winding fluxes in vector form, Eq. 3-61
fl_sd_0 = fl_dq_0(1)
fl_sq_0 = fl_dq_0(2)         
fl_rd_0 = fl_dq_0(3)
fl_rq_0 = fl_dq_0(4)
[thetar, fl_r_dq_0]=cart2pol(fl_rd_0, fl_rq_0)
[thetas, fl_s_dq_0]=cart2pol(fl_sd_0, fl_sq_0)

% d-axis is now aligned with the rotor flux which results in the following new values:
fl_rq_0=0;          %fl_rq_0 equals zero
fl_rd_0=fl_r_dq_0        
[fl_sd_0, fl_sq_0]=pol2cart(thetas-thetar, fl_s_dq_0)
