clear all
clc
% Example 5-3 File Name EX5_3calc.m
% Calculation of Initial Conditions
% Induction Motor Parameters
Rs=0.002;
Rr=0.0015;
Xls=0.05;
Xlr=0.047;
Xm=0.86;
Jeq=70;
p=6;

% Steady State Operating Condition
f=60; VLLrms= 690; s=0.01;                   % phase-a voltage is at its positive peak at t=0
Wsyn=2*pi*f;                                            % synchronous speed in electrical rad/s
Wm=(1-s)*Wsyn;                                          % rotor speed in electrical rad/s

% Phasor Calculations
Va = VLLrms * sqrt(2)/ sqrt(3);                         % Va phasor

% Space Vectors at time t=0 with stator a-axis as the reference
Vs_0 = (3/2) * Va;                                      % Vs(0) space vector
Theta_Vs_0 = angle(Vs_0);                               % angle of Vs(0) space vector

% We will assume that at t=0, d-axis is aligned to the stator a-axis.  Therefore, Theta_da_0=0
Theta_da_0 = 0;
Vsd_0 = sqrt(2/3) * abs(Vs_0) * cos(Theta_Vs_0 - Theta_da_0); % similar to Eq. 3-64
Vsq_0 = sqrt(2/3) * abs(Vs_0) * sin(Theta_Vs_0 - Theta_da_0); % similar to Eq. 3-65

% Calculation of machine inductances 
Ls = (Xls + Xm) / (2*pi*f);
Lm = Xm / (2*pi*f);
Lr = (Xlr + Xm) / (2*pi*f);
tau_r=Lr/Rr;

% Calculations of dq-winding currents
A = [Rs        -Wsyn*Ls       0         -Wsyn*Lm  ;...
     Wsyn*Ls    Rs            Wsyn*Lm    0        ;...
     0         -s*Wsyn*Lm     Rr        -s*Wsyn*Lr;...      % Matrix [A] in Eq. 3-70
     s*Wsyn*Lm  0             s*Wsyn*Lr  Rr];
Ainv = inv(A);
V_dq_0=[Vsd_0; Vsq_0; 0; 0];
I_dq_0=Ainv*V_dq_0;
Isd_0=I_dq_0(1)
Isq_0=I_dq_0(2)
Ird_0=I_dq_0(3)
Irq_0=I_dq_0(4)

% Electromagnetic Torque, which equals Load Torque in Initial Steady State
Tem_0 = (p/2) * Lm * (Isq_0 * Ird_0 - Isd_0 * Irq_0)    % Eq. 3-47
TL_0 = Tem_0

% Wmech = rotor speed in actual rad/s
Wmech_0=(2/p)*Wm      % Eq. 3-34          

% Inductance matrix M in Eq. 3-61
M = [Ls 0  Lm 0 ;...
     0  Ls 0  Lm;...
     Lm 0  Lr 0 ;...
     0  Lm 0  Lr];

% dq winding Flux Linkages with the d-axis aligned with the stator a-axis
fl_dq_0 = M * [Isd_0; Isq_0; Ird_0; Irq_0];    % dq-winding fluxes in vector form, Eq. 3-61
fl_sd_0 = fl_dq_0(1)
fl_sq_0 = fl_dq_0(2)         
fl_rd_0 = fl_dq_0(3)
fl_rq_0 = fl_dq_0(4)
[thetar, fl_r_dq_0]=cart2pol(fl_rd_0, fl_rq_0)
[thetas, fl_s_dq_0]=cart2pol(fl_sd_0, fl_sq_0)
[theta_Is_dq, Is_dq_0]=cart2pol(Isd_0, Isq_0)
[theta_Vs_dq, Vs_dq_0]=cart2pol(Vsd_0, Vsq_0)

% d-axis is now aligned with the rotor flux which results in the following new values:
fl_rd_0=fl_r_dq_0       %fl_rq_0 equals zero
[fl_sd_0, fl_sq_0]=pol2cart(thetas-thetar, fl_s_dq_0)
[Isd_0, Isq_0]=pol2cart(theta_Is_dq-thetar, Is_dq_0)
[Vsd_0, Vsq_0]=pol2cart(theta_Vs_dq-thetar, Vs_dq_0)

% Calculations for the controller in Fig. 5-9 based on Chapter 8 of Reference [1]
Wc=25; % crossover freq in rad/s
k=(p/2)*(Lm*Lm/Lr)*Isd_0;               % Eq. 5-14
PM=60*pi/180;                           % phase margin in rad/s
Wc_kp_by_ki=tan(PM);                    % kp and ki are shown in Fig. 5-9
ki=Wc*Wc*Jeq/(k*sqrt(1+(tan(PM)^2)))
kp=ki*Wc_kp_by_ki/Wc

% check to show that at Wc,  GOLmag=1 and GOLang= (-180 degrees + phase margin of 60 degrees)
GOL=(kp+ki/(j*Wc))*k/(Jeq*j*Wc)         % open-loop transfer function
GOLmag=abs(GOL)
GOLang=angle(GOL)*180/pi

% PI in current loop
sigma=1-Lm*Lm/(Ls*Lr)       % Eq. 5-15
Wci=10*Wc                   % Current-loop bandwidth is qi times that of the speed loop
PMi=PM
Wci_kpi_by_kii=tan(PMi-pi/2+atan(Wci*Ls*sigma/Rs))
kii=Wci*sqrt(Rs*Rs+(Wci*Ls*sigma)^2)/sqrt(Wci_kpi_by_kii^2+1)
kpi=Wci_kpi_by_kii*kii/Wci

% check to show that at Wci,  GOLimag=1 and GOLiang= (-180 degrees + phase margin of 60 degrees)
GOLi=(kpi+kii/(j*Wci))/(Rs+j*Wci*Ls*sigma)
GOLimag=abs(GOLi)
GOLiang=angle(GOLi)*180/pi







