clear all
clc
V=690*(2/3)^0.5;
omega=2*pi*60;
Xm = 860e-3;
Xls = 50e-3;
Xlr = 47e-3;
Rs = 2e-3;
Rr = 1.5e-3;
J = 70;
p=6;
Wsyn = omega;
s = 0.01;
slip = s;

Lm = Xm/omega;
Lls = Xls/omega;
Llr = Xlr/omega;
Ls = Lm+Lls;
Lr = Lm+Llr;
sigma = 1-Lm^2/(Ls*Lr);

%Initial conditions
V_rms = 690/3^0.5;
Zr = Rr/s+1i*Xlr;
Zm = 1i*Xm;
Zs = Rs+1i*Xls;
Z = Zs + Zm*Zr/(Zm+Zr);
Is_rms = V_rms/Z;
Ir_rms = -Is_rms*Zm/(Zm+Zr);
Wmech_0 = (2/p)*Wsyn*(1-s);
P = 3*abs(Ir_rms)^2*Rr*(1-s)/s;
T_em = P/Wmech_0;
T_l = T_em;

Vsd_0 = V_rms*3^0.5;
Vrd_0 = 0;
Vrq_0 = 0;

theta_Is = angle(Is_rms);
theta_Ir = angle(Ir_rms);

Isd_0 = (3^0.5)*abs(Is_rms)*cos(theta_Is);
Isq_0 = (3^0.5)*abs(Is_rms)*sin(theta_Is);
Ird_0 = (3^0.5)*abs(Ir_rms)*cos(theta_Ir);
Irq_0 = (3^0.5)*abs(Ir_rms)*sin(theta_Ir);

Qs_0 = -Vsd_0*Isq_0;
Qs_0 = (Vsd_0)^2/(Wsyn*Ls)+(Lm/Ls)*Vsd_0*Irq_0;

M = [Ls 0 Lm 0; 
     0 Ls 0 Lm;
     Lm 0 Lr 0;
     0 Lm 0 Lr];

fl_dq_0 =  M*[Isd_0; Isq_0; Ird_0; Irq_0];
fl_sd_0 = fl_dq_0(1);
fl_sq_0 = fl_dq_0(2);
fl_rd_0 = fl_dq_0(3);
fl_rq_0 = fl_dq_0(4);

%Speed controller design
wc_w = 1*2*pi;
phi_m_w = pi/3;
s = tf('s');
k_w_tf = -p*Vsd_0*Lm/(2*Wsyn*Ls*J);
G_ol_w = k_w_tf/s;
kpw_by_kiw = (1/wc_w)*tan(phi_m_w);
kiw = wc_w^2/(k_w_tf*sqrt(1+(kpw_by_kiw*wc_w)^2));
kpw = kpw_by_kiw*kiw;
G_loop_w = G_ol_w*(kpw+kiw/s);
%bode(G_loop_w); grid on;

%Current controller design
wc_i = 10*2*pi;
phi_m_i = pi/3;
G_ol_i = 1/(Rr+sigma*Lr*s);
kpi_by_kii = (1/wc_i)*tan(-pi/2+phi_m_i+atan(sigma*Lr*wc_i/Rr));
kii = wc_i*sqrt(Rr^2+(sigma*Lr*wc_i)^2)/sqrt(1+(kpi_by_kii*wc_i)^2);
kpi = kpi_by_kii * kii;
G_loop_i = G_ol_i*(kpi+kii/s);
%figure(2);
%bode(G_loop_i); grid on;


