clear all
clc
f=60;
omega_syn = 2*pi*f;
Vll_rms = 575;
Vphase = Vll_rms/(3^0.5);
Xm = 576e-3;
Xls = 34e-3;
Xlr = 31e-3;
Rs = 1.4e-3;
Rr = 0.991e-3; 
s = 0.01;
p=6;
J=75;
omega_mech_syn = 2*pi*f/(p/2);
Lm = (Xm/omega_syn);
Lls = Xls/omega_syn;
Llr = Xlr/omega_syn;
Ls = Lm+Lls;
Lr = Lm+Llr;
L = [Ls, 0, Lm, 0;
     0, Ls, 0, Lm;
     Lm, 0, Lr, 0;
     0, Lm, 0, Lr];
 
sigma = 1-Lm^2/(Ls*Lr);
tau_r = Lr/Rr;

Zs = Rs + 1i*Xls;
Zr = Rr/s + 1i*Xlr;
Zm = 1i*Xm;
Z = Zs + Zm*Zr/(Zm+Zr);
Isphase = Vphase/Z;
Irphase = Isphase*Zm/(Zm+Zr);
P_out = 3*(abs(Irphase)^2)*Rr*(1-s)/s;
Torque = P_out/(omega_mech_syn*(1-s));

Is = (3/2)*(2^0.5)*Isphase;
Ir = -(3/2)*(2^0.5)*Irphase; %Ir is in opposite direction in the dq model as 
                         %compared to the equivalent circuit
theta_Is_0 = angle(Is);
theta_Ir_0 = angle(Ir);
%Initial conditions for synchronous frame. Voltage vector, d axis and rotor
%A axis are assumed to be aligned along stator a axis initially
% Vsd = (3/2)*Vphase;
% Vsq = 0;
theta_da_0 = 0;
theta_dA_0 = 0;
theta_m_0 = theta_da_0 - theta_dA_0;
omega_m_0 = omega_syn*(1-s);
Isdq_syn_0 = ((2/3)^0.5) * Is * exp(1i*(-theta_da_0));
Irdq_syn_0 = ((2/3)^0.5) * Ir * exp(1i*(-theta_da_0));
Isd_0 = real(Isdq_syn_0);
Isq_0 = imag(Isdq_syn_0);
Ird_0 = real(Irdq_syn_0);
Irq_0 = imag(Irdq_syn_0);
lambda_dq_synframe = L*[Isd_0; Isq_0; Ird_0; Irq_0];
T_em = (p/2)*Lm*(Isq_0 * Ird_0 - Isd_0 * Irq_0);

%Initial conditions for stator flux frame.
I_dq = [Isd_0; Isq_0; Ird_0; Irq_0];
Fl_dq = L*I_dq;
Fl_s = Fl_dq(1)+Fl_dq(2)*1i;
Fl_r = Fl_dq(3)+Fl_dq(4)*1i;
fl_s_angle = angle(Fl_s);
fl_r_angle = angle(Fl_r);
theta_da_flsframe = fl_s_angle;
theta_dA_flsframe = theta_dA_0 + (theta_da_flsframe - theta_da_0);

Fl_r_flsframe = Fl_r * exp(-1i*theta_da_flsframe);

Fl_s_d_flsframe = abs(Fl_s);
Fl_s_q_flsframe = 0;
Fl_r_d_flsframe = real(Fl_r_flsframe);
Fl_r_q_flsframe = imag(Fl_r_flsframe);
Idq_0_flsframe = inv(L)*[Fl_s_d_flsframe; Fl_s_q_flsframe; Fl_r_d_flsframe; Fl_r_q_flsframe];

Vs_dq = ((2/3)^0.5)*(3/2)*(2^0.5)*Vphase*exp(-1i*theta_da_flsframe);
Vsd_0_flsframe = real(Vs_dq);
Vsq_0_flsframe = imag(Vs_dq);

Wmech_0 = 2*pi*f*(1-s)*2/p;
%Stator flux P controller
wc_lambdas = 15*pi*2;
kp_lambdas = wc_lambdas

%Speed loop PI controller 
wc_w = 1*pi*2;
phi_m = 60;
kpw_by_kiw = tand(phi_m)/wc_w;
kiw = J*wc_w/((kpw_by_kiw^2+1/(wc_w^2))^0.5)
kpw = kpw_by_kiw*kiw

%Torque PI controller
wc_t = 15*pi*2;
phi_m_t = 90;
Req = Rr*Ls/Lm;
Leq = Ls*Lr/Lm-Lm;
tau_eq = Leq/Req;
% k1 = 1 + Rs*Fl_r_d_flsframe/(Req*Fl_s_d_flsframe) + ((p/2)^2)*(Fl_s_d_flsframe*Fl_r_d_flsframe/(J*Req));
k1 = 1 + Rs*Fl_r_d_flsframe/(Req*Fl_s_d_flsframe) ;
kpt_by_kit = (1/wc_t)*tan(-pi/2+phi_m_t*pi/180+atan(tau_eq*wc_t/k1));
kit = 2*Req*(((tau_eq*wc_t)^2+k1^2)^0.5)/(p*Fl_r_d_flsframe*((kpt_by_kit^2+1/(wc_t^2))^0.5))
kpt = kpt_by_kit*kit

% Torque controller initial output
a = (omega_m_0*Fl_r_d_flsframe + Rr*Idq_0_flsframe(2)*Ls/Lm + Rs*Idq_0_flsframe(2)*(Fl_r_d_flsframe/Fl_s_d_flsframe))/(Fl_r_d_flsframe/Fl_s_d_flsframe);