clear all
clc
% Example 8-1; File Name EX8_1calc.m
% Calculation of Initial Conditions
% Induction Motor Parameters
Rs=0.002; 
Rr=0.0015;
Xls=0.05;
Xlr=0.047;
Xm=0.86;
Jeq=70;
p=6;
% Steady State Operating Condition
f=60; VLLrms= 690; s=0.01;  % phase-a voltage is at its positive peak at t=0
Wsyn=2*pi*60;                                           % synchronous speed in rad/s
Wd=Wsyn                                                 % speed of d-axis
WdA= s *Wsyn;                                           % slip speed
Wm=(1-s)*Wsyn;                                          % rotor speed in electrical rad/s
% Phasor Calculations
Va = VLLrms * 2^0.5 / 3^0.5;                            % Va phasor
% Space Vectors at time t=0 with stator a-axis as the reference
Vs_0 = (3/2) * Va;                                      % Vs(0) space vector
Theta_Vs_0 = angle(Vs_0);                               % angle of Vs(0) space vector
% We will assume that at t=0, d-axis is aligned to the stator a-axis.  Therefore, Theta_da_0=0
Theta_da_0 = 0;
Vsd_0 = (2/3)^0.5 * abs(Vs_0) * cos(Theta_Vs_0 - Theta_da_0); % similar to Eq. 3-64
Vsq_0 = (2/3)^0.5 * abs(Vs_0) * sin(Theta_Vs_0 - Theta_da_0); % similar to Eq. 3-65
% Calculation of machine inductances 
Ls = (Xls + Xm) / (2*pi*f);
Lm = Xm / (2*pi*f);
Lr = (Xlr + Xm) / (2*pi*f);
tau_r=Lr/Rr;
% Inductance matrix L in Eq. 3-62
L = [Ls Lm;...
     Lm Lr];
% Matrix A in Eq. 3-##
A = [Rs -Wd*Ls 0 -Wd*Lm;...
     Wd*Ls Rs Wd*Lm 0;...
     0 -WdA*Lm Rr -WdA*Lr;...
     WdA*Lm 0 WdA*Lr Rr];
Ainv = inv(A);
Vvector=[Vsd_0; Vsq_0; 0; 0];
Ivector=Ainv*Vvector;
Isd_0=Ivector(1)
Isq_0=Ivector(2)
Ird_0=Ivector(3)
Irq_0=Ivector(4)

% Electromagnetic Torque, which equals Load Torque in Initial Steady State
Tem_0 = (p/2) * Lm * (Isq_0 * Ird_0 - Isd_0 * Irq_0)    % Eq. 3-47
TL_0 = Tem_0

% Wmech = rotor speed in actual rad/s
Wmech_0=(2/p)*Wm      % Eq. 3-34          

% Inductance matrix M in Eq. 3-61
M = [Ls 0  Lm 0 ;...
     0  Ls 0  Lm;...
     Lm 0  Lr 0 ;...
     0  Lm 0  Lr];

% dq winding Flux Linkages with the d-axis aligned with the stator a-axis
fl_dq_0 = M * [Isd_0; Isq_0; Ird_0; Irq_0];    % dq-winding fluxes in vector form, Eq. 3-61
fl_sd_0 = fl_dq_0(1)
fl_sq_0 = fl_dq_0(2)         
fl_rd_0 = fl_dq_0(3)
fl_rq_0 = fl_dq_0(4)
[thetar, fl_r_dq_0]=cart2pol(fl_rd_0, fl_rq_0)
[thetas, fl_s_dq_0]=cart2pol(fl_sd_0, fl_sq_0)
[theta_Is_dq, Is_dq_0]=cart2pol(Isd_0, Isq_0)
[theta_Vs_dq, Vs_dq_0]=cart2pol(Vsd_0, Vsq_0)

% d-axis is now aligned with the rotor flux which results in the following new values:
fl_rq_0=0;              %fl_rq_0 equals zero
fl_rd_0=fl_r_dq_0
fl_sd_0_vs=fl_sd_0;
fl_sq_0_vs=fl_sq_0;
[fl_sd_0, fl_sq_0]=pol2cart(thetas-thetar, fl_s_dq_0)
[Isd_0, Isq_0]=pol2cart(theta_Is_dq-thetar, Is_dq_0)
[Vsd_0, Vsq_0]=pol2cart(theta_Vs_dq-thetar, Vs_dq_0)
fl_s_0=sqrt(3/2)*fl_s_dq_0;
sigma=1-(Lm*Lm)/(Ls*Lr);
Lsigma=sqrt(Ls*Lr-Lm*Lm);

Vd=1000
Vtri=5
fs=10e3

% Three level hysterisis control selection table
% The first index is the torque command :1->Decrease torque;2->Apply zero vecor;3->Increase torque
% The second index is the stator flux command: 1->Decrease flux;2->Increase flux
% The third index is the stator flux sector number 1-6

% The following is to Decrease Torque
U(1,:,:)=[  4   5   1   3   2   6   ;...
            5   1   3   2   6   4   ];
    
% The following is to Apply Zero Vector as determined by torque controller (indepenent of flux controller)
U(2,:,:)=[  0   7   0   7   0   7   ;...
            7   0   7   0   7   0   ];
% The following is to Increase torque
U(3,:,:)=[  2   6   4   5   1   3   ;...
            3   2   6   4   5   1   ];
    
delta_Tem=0.05*Tem_0
delta_flux=0.005*fl_s_0
Tsample=25e-6
Tsample_speed=500e-6

% Based on the voltage vector number, inverter switch signals q(t) are selected for phases a-b-c.
Q=[0    1   0   1   0   1   0   1;...
   0    0   1   1   0   0   1   1;...
   0    0   0   0   1   1   1   1];


% controller calculations for example 5_2
Wc=25; % crossover freq in rad/s
PM=60*pi/180; % phase margin in rad/s
Wc_kp_by_ki=tan(PM);
ki=Wc*Wc*Jeq/(sqrt(1+(tan(PM)^2)))
kp=ki*Wc_kp_by_ki/Wc
